@@ -1,8 +1,8 @@
 package org.acme.scheduler;
 
-import io.quarkus.test.junit.NativeImageTest;
+import io.quarkus.test.junit.QuarkusIntegrationTest;
 
-@NativeImageTest
+@QuarkusIntegrationTest
 public class CountResourceIT extends CountResourceTest {
 
 }
\ No newline at end of file
